@@ -1,17 +1,16 @@
-{-# LANGUAGE CPP              #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 module Test.QuickCheck.Instances.Solo () where
 
 import Prelude ()
 import Test.QuickCheck.Instances.CustomPrelude
 
-import Data.Tuple.Solo (Solo (Solo), getSolo)
+import Data.Tuple.Solo (Solo (MkSolo), getSolo)
 
 import Test.QuickCheck
 
 instance Arbitrary1 Solo where
-  liftArbitrary = fmap Solo
-  liftShrink shr = map Solo . shr . getSolo
+  liftArbitrary = fmap MkSolo
+  liftShrink shr = map MkSolo . shr . getSolo
 
 instance Arbitrary a => Arbitrary (Solo a) where
   arbitrary = arbitrary1
@@ -21,4 +20,4 @@ instance CoArbitrary a => CoArbitrary (Solo a) where
   coarbitrary = coarbitrary . getSolo
 
 instance Function a => Function (Solo a) where
-  function = functionMap getSolo Solo
+  function = functionMap getSolo MkSolo
